package mirage-clock

  1. Overview
  2. Docs
On This Page
  1. Monotonic clock
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module type Mirage_clock.MCLOCKSource

Monotonic clock

Clock returning monotonic time since an arbitrary point. To be used for eg. profiling.

include Mirage_device.S with type t = unit
Sourcetype +'a io

The type for potentially blocking I/O operation

Sourcetype t = unit

The type representing the internal state of the device

Sourceval disconnect : t -> unit io

Disconnect from the device. While this might take some time to complete, it can never result in an error.

Sourceval elapsed_ns : t -> int64

elapsed_ns () is a monotonically increasing count of nanoseconds elapsed since some arbitrary point

Sourceval period_ns : t -> int64 option

period_ns () is Some ns representing the clock's nanosecond period ns, if known